@@ -2,9 +2,9 @@ from nacl.signing import SigningKey
 import base64
 import hashlib
 
-def hash_and_sign(cmd_json, priv_key):
+def hash_and_sign(s, priv_key):
   # Turn the json into a byte string
-  cmd_data = bytes(cmd_json, encoding="utf8")
+  cmd_data = bytes(s, encoding="utf8")
 
   # Create the signature
   sk = SigningKey(bytes.fromhex(priv_key))
@@ -12,8 +12,8 @@ def hash_and_sign(cmd_json, priv_key):
   # Create the hash code
   hash_bytes = blake2b(cmd_data)
   hash_code = base64.urlsafe_b64encode(hash_bytes).decode().rstrip('=')
-
-  return hash_code, sk.sign(hash_bytes).hex()
+  
+  return hash_code, sk.sign(hash_bytes).signature.hex()
 
 
 def blake2b(bytes):
